@@ -2,7 +2,7 @@
 """
 Stress-test your web app.
 
-(c) 2020 Martin Wendt and contributors; see https://github.com/mar10/stressor
+(c) 2020-2021 Martin Wendt and contributors; see https://github.com/mar10/stressor
 Licensed under the MIT license: https://www.opensource.org/licenses/mit-license.php
 
 Usage examples:
@@ -180,10 +180,13 @@ def run():
         help="optional HAR file that is converted",
     )
     sp.add_argument(
-        "--force", action="store_true", help="override existing files",
+        "--force",
+        action="store_true",
+        help="override existing files",
     )
     sp.add_argument(
-        "--opts", help="YAML file with conversion options",
+        "--opts",
+        help="YAML file with conversion options",
     )
     sp.set_defaults(command=handle_init_command)
 
