@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# (c) 2020 Martin Wendt and contributors; see https://github.com/mar10/stressor
+# (c) 2020-2021 Martin Wendt and contributors; see https://github.com/mar10/stressor
 # Licensed under the MIT license: https://www.opensource.org/licenses/mit-license.php
 """
 """
@@ -178,6 +178,8 @@ def init_logging(verbose=3, path=None):
         # format="%(asctime)s.%(msecs)d <%(process)d.%(thread)d> %(message)s",
         datefmt="%H:%M:%S",
     )
+    # Make sure it is set (when running from tox, the above basicConfig() did not set it)
+    logger.setLevel(level)
 
     if path:
         if os.path.isdir(path):
